# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2020-09-15 12:22
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0003_add_translations_and_url_filtering'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='external_id',
            field=models.IntegerField(help_text='Used to reference externally created notifications', null=True),
        ),
        migrations.AlterField(
            model_name='notification',
            name='look',
            field=models.CharField(choices=[('SIGN_COMPANY', 'SIGN_COMPANY'), ('SIMPLE_OK', 'SIMPLE_OK'), ('RELEASE_NOTES', 'RELEASE_NOTES')], default='SIMPLE_OK', help_text='This controls the appearance of the notification.', max_length=50),
        ),
        migrations.AlterField(
            model_name='notification',
            name='name_en',
            field=models.CharField(help_text='Used to reference notification, shown in title for some looks', max_length=250, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='notification',
            name='name_is',
            field=models.CharField(help_text='Used to reference notification, shown in title for some looks', max_length=250, null=True, unique=True),
        ),
    ]
